
nbsphinx-link
=====================================

Version: |release|

**nbsphinx-link** is a `sphinx`_ extension built on `nbsphinx`_ that
allows you to include Jupyter notebooks that sit outside your sphinx source
directory in your documentation.


In this documentation, the Installation section is written as a
notebook included with nbsphinx, while the Introduction section
is written as a notebook included with nbsphinx-link.


Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Installation and usage

   installing
   introduction



.. links

.. _`sphinx`: http://www.sphinx-doc.org

.. _`nbsphinx`: https://nbsphinx.readthedocs.io
